/* eslint-disable react/prop-types */
import { h, Fragment } from 'preact'
import { useState, useEffect } from 'preact/hooks'
import { isFuture, isPast } from 'date-fns'
import striptags from 'striptags'

import { H1 } from '../../components/Text'
import Markdown from '../../components/Markdown'
import translations from '../../data/strings'
import InfoLayout from '../../components/InfoLayout'
import VideoEmbed from '../../components/VideoEmbed'
import {
  EpisodeCard,
  Title,
  InfoContent,
  PositionedCross as CrossSvg,
  Row,
  ActionButton as Button,
  Trailer,
} from './styles'

import intro from '../../data/intro.md'
// import credits from '../../data/credits.md'

import config from '../../data/config'
import trailerThumb from '../../assets/img/main_thumb.png'

const SeriesPage = ({ data }) => {
  const trailerUrl = `https://www.youtube-nocookie.com/embed/${config.seriesTrailerId}?autoplay=1&vq=hd1080`
  const [embedURL, setEmbedUrl] = useState('')

  const onClickTrailerButton = () => {
    setEmbedUrl(trailerUrl)
  }
  const deactivateEmbed = () => {
    setEmbedUrl('')
  }

  console.log({ past: data.episodes.past, future: data.episodes.future })

  const credits = `
  ## Credits
  ${data.credits}
  `

  const dateString = `${new Date()}`
  let tzShort =
    // Works for the majority of modern browsers
    dateString.match(/\(([^\)]+)\)$/) ||
    // IE outputs date strings in a different format:
    dateString.match(/([A-Z]+) [\d]{4}$/)

  if (tzShort) {
    // Old Firefox uses the long timezone name (e.g., "Central
    // Daylight Time" instead of "CDT")
    tzShort = tzShort[1].match(/[A-Z]/g).join('')
  }

  return (
    <InfoLayout title={data.title} subtitle={striptags(data.subtitle)} image={data.image}>
      {embedURL ? (
        <VideoEmbed onClose={deactivateEmbed} url={embedURL} />
      ) : null}
      <Fragment>
        <InfoContent>
          <H1>{data.title}:</H1>
          <H1>{data.subtitle}</H1>
          <Markdown withLinebreaks>{data.description}</Markdown>

          <Trailer imgSrc={trailerThumb} onClick={onClickTrailerButton} />

          <Row>
            <a
              href="https://discord.gg/Xu9D3qVana"
              target="_blank"
              rel="noopener noreferrer"
            >
              <Button>Join the Discord</Button>
            </a>
            <a
              href="https://ndc.substack.com/subscribe"
              target="_blank"
              rel="noopener noreferrer"
            >
              <Button>Subscribe to the mailing list</Button>
            </a>
          </Row>
        </InfoContent>
        {/* {currentVideo && (
          <Fragment>
            <Title>{translations.en.nowPlaying}:</Title>
            <EpisodeCard {...currentVideo} />
          </Fragment>
        )}

      */}
        {data.episodes.future.length ? (
          <Fragment>
            <Title>{translations.en.nextStream}:</Title>
            {data.episodes.future.map(feeditem => (
              <EpisodeCard
                key={feeditem.start}
                tzShort={tzShort}
                {...feeditem}
              />
            ))}
          </Fragment>
        ) : null}
        {data.episodes.past.length ? (
          <Fragment>
            <Title>Past streams:</Title>
            {data.episodes.past.map(feeditem => (
              <EpisodeCard
                key={feeditem.beginsOn}
                hasPassed
                onClickButton={() =>
                  setEmbedUrl(`${config.peertube_root}${feeditem.embedPath}`)
                }
                {...feeditem}
              />
            ))}
          </Fragment>
        ) : null}
        <InfoContent>
          <Title>Credits</Title>
          <Markdown>{credits}</Markdown>
        </InfoContent>
      </Fragment>

    </InfoLayout>
  )
}

export default SeriesPage
